@@ -75,6 +75,7 @@ def generate_report(scan_id, apikey, baseurl):
         if response.status_code not in [200, 201]:
             error_exit("failed to generate report")
         logger.info(f"Starting generate report...")
+        time.sleep(5)
 
 
 def generate_remediation_report(baseurl, apikey, scan_id, output_folder):
@@ -94,12 +95,16 @@ def generate_remediation_report(baseurl, apikey, scan_id, output_folder):
         writer = csv.writer(f)
         writer.writerow(header)
         for scan_issue in scan_issue_list:
-            scan_issue_info = get_scan_issue_detail(baseurl, apikey, scan_issue)
+            scan_issue_info = get_scan_issue_detail(baseurl, apikey, scan_issue["id"])
             line = [
                 scan_issue_info["id"],
                 scan_issue_info["library_version"],
-                scan_issue_info["recommendation"]["fixed_library_version"],
-                scan_issue_info["fixed_library_version"]["version_number"],
+                scan_issue_info["recommendation"]["fixed_library_version"]
+                if scan_issue_info["recommendation"]
+                else "",
+                scan_issue_info["fixed_library_version"]["version_number"]
+                if scan_issue_info["fixed_library_version"]
+                else "",
             ]
             writer.writerow(line)
     logger.info(f"Successfully generating remediation report in {output_folder}...")
@@ -130,26 +135,31 @@ def download_report(scan_id, apikey, baseurl, report_format, output_path=None):
 
     while length > 0:
         for key, url in download_dict.items():
-            content = check_generate(url, header, query)
+            if url == "finished":
+                continue
 
-            if not content:
+            download_link = check_generate(url, header, query)
+
+            if not download_link:
                 time.sleep(5)
                 continue
 
             length -= 1
-            if report_format == "csv":
-                content = base64.decodebytes(content)
+            download_dict[key] = "finished"
 
-            with open(
-                os.path.join(
-                    output_path,
-                    f"scan-{scan_id}-{key}.csv"
-                    if report_format == "csv"
-                    else f"scan-{scan_id}-{key}.pdf",
-                ),
-                "wb",
-            ) as f:
-                f.write(content)
+            response = requests.get(download_link)
+
+            if response.status_code == 200:
+                with open(
+                    os.path.join(
+                        output_path,
+                        f"scan-{scan_id}-{key}.csv"
+                        if report_format == "csv"
+                        else f"scan-{scan_id}-{key}.pdf",
+                    ),
+                    "wb",
+                ) as f:
+                    f.write(response.content)
     logger.info(f"Successful download scan report!")
 
 
@@ -158,6 +168,5 @@ def check_generate(url, header, query):
     if response.status_code not in [200, 201]:
         return None
 
-    content = response.content
-    content = base64.decodebytes(content)
-    return content
+    download_link = response.json()["download_link"]
+    return download_link
